@@ -1,6 +1,6 @@
 import os
 
-from fabric.api import local, run, put, cd
+from fabric.api import local, run, put, lcd, cd
 
 from .containers import conf
 from .task import Task
@@ -9,18 +9,7 @@ from .task import Task
 __all__ = ['push', 'push_files']
 
 
-class Push(Task):
-    @conf
-    def exclude_string(self):
-        excludes = ['*.pyc', '*.pyo']
-        exclude_string = ' '.join(['--exclude "%s"' % pattern
-                                   for pattern in excludes])
-
-        if os.path.exists('%(src_path)s/.excludes' % self.conf):
-            exclude_string = '--exclude-from .excludes ' + exclude_string
-
-        return exclude_string
-
+class PushTask(Task):
     @conf
     def src_file(self):
         if 'src_file' not in self.conf:
@@ -35,6 +24,19 @@ class Push(Task):
                 '%(target_path)s/fabdeploy_%(current_time)s.tar' % self.conf
         return self.conf.target_file
 
+
+class Push(PushTask):
+    @conf
+    def exclude_string(self):
+        excludes = ['*.pyc', '*.pyo']
+        exclude_string = ' '.join(['--exclude "%s"' % pattern
+                                   for pattern in excludes])
+
+        if os.path.exists('%(src_path)s/.excludes' % self.conf):
+            exclude_string = '--exclude-from .excludes ' + exclude_string
+
+        return exclude_string
+
     def do(self):
         local('tar %(exclude_string)s '
               '--create '
@@ -53,20 +55,21 @@ class Push(Task):
 push = Push()
 
 
-class PushFiles(Push):
+class PushFiles(PushTask):
     def do(self):
-        if self.files:
-            self.conf._files = \
-                '--add-file ' + '--add-file '.join(self.conf.files)
+        if isinstance(self.conf.files, list):
+            files = self.conf.files
         else:
-            self.conf._files = ''
+            files = [f.strip() for f in self.conf.files.split(',')]
+        self.conf._files = '--add-file ' + '--add-file '.join(files)
 
-        local(
-            'tar'
-            '--create'
-            '--gzip'
-            '--file %(src_file)s'
-            '%(_files)s')
+        with lcd(self.conf.src_path):
+            local(
+                'tar '
+                '--create '
+                '--gzip '
+                '--file %(src_file)s '
+                '%(_files)s' % self.conf)
         put(self.conf.src_file, self.conf.target_file)
         local('rm %(src_file)s' % self.conf)
         with cd(self.conf.target_path):
